@@ -46,7 +46,7 @@ print('Now calculating velocities...')
 
 # =============================================================================
 # Supercell and BZ cration
-Nqs_path, ks_path, ks_scaled_path, kk, Hk = util.get_commensurate_kpath(file_initial_conf, N1,N2,N3, N1,N2,N3, kinput_scaled)
+Nqs_path, ks_path, ks_scaled_path, kk, x_labels, Hk = util.get_commensurate_kpath(file_initial_conf, N1,N2,N3, N1,N2,N3, kinput_scaled, np.array([' ' for i in range(len(kinput_scaled))]))
 SCell, Ruc, Suc, R0, R0_repeat, S0, masses, masses_uc = read.read_SPOSCAR_and_masses(file_initial_conf, n_atom_unit_cell, Masses, N1, N2, N3)
 # =============================================================================
 
@@ -84,24 +84,22 @@ C = Ctot[0:int(len(Ctot)/2)].real
 quasiparticles_kpoints, quasiparticles_info = np.zeros((Nqs_path, 3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3))
 print('\nDone. Performing calculation of renormalised FORCE CONSTANTS...\n')
 kpoints_scal, kpoints = util.get_kgrid(N1,N2,N3, Hk)
-irr_kpoints, irr_kpoints_scal, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scal)
-Ds = np.zeros((len(irr_kpoints),tot_atoms_uc*3, tot_atoms_uc*3), dtype=complex)
-for i in range(len(irr_kpoints)):
-    k = irr_kpoints[i]
-    k_scal = irr_kpoints_scal[i]
-    thisk_permutations = permutations_types[i]
-    weight = weights[i]
-    print('\t irr kpoint scaled: ', i, k_scal)
-    print('\t weight: ', weight)
+# you're not using irreducible kpoints anymore, couse it doesn't work for BaTiO3, unless you do adjustments
+# irr_kpoints, irr_kpoints_scal, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scal)
+Ds = np.zeros((len(kpoints),tot_atoms_uc*3, tot_atoms_uc*3), dtype=complex)
+for i in range(len(kpoints)):
+    k = kpoints[i]
+    k_scal = kpoints_scal[i]
+    # thisk_permutations = permutations_types[i]
+    # weight = weights[i]
+    print('\t kpoint scaled: ', i, k_scal)
+    # print('\t weight: ', weight)
     
 # =============================================================================
 # harmonic things
     D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
-    eigvals, eigvec = np.linalg.eigh(D)
-    idx = np.argsort(eigvals)
-    eigvals = eigvals[idx]
-    omegas = np.sqrt(eigvals)/2/np.pi
-    eigvec, eigvecH = eigvec[:,idx], np.conjugate(eigvec[:,idx].T)
+    eigvals, eigvecs, omegas = util.get_eigvals_eigvec(D)
+    eigvecH = np.conjugate(eigvecs.T)
 # =============================================================================
     
 # =============================================================================
@@ -138,7 +136,7 @@ for i in range(len(irr_kpoints)):
     eigvals_renorm = (Params[0,:]*2*np.pi)**2
     omegas_renorm = np.sqrt(eigvals_renorm)/2/np.pi
     Lamdas_renorm = np.diag(eigvals_renorm)
-    D_renorm = np.dot(np.dot(eigvec,Lamdas_renorm),eigvecH)
+    D_renorm = np.dot(np.dot(eigvecs,Lamdas_renorm),eigvecH)
     Ds[i,:,:] = D_renorm*np.sqrt(np.outer(masses_uc, masses_uc))
 # =============================================================================
 
@@ -167,7 +165,7 @@ util.save('ZS', ZS)
 
 
 # SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
-# K_renormold = util.get_K_renorm_old(tot_atoms_uc,N1,N2,N3, SCell, R0, kpoints, Ds)
-K_renorm = util.get_K_renorm(tot_atoms_uc,N1,N2,N3, SCell, R0, irr_kpoints, permutations_types, Ds)
+K_renorm = util.get_K_renorm_old(tot_atoms_uc,N1,N2,N3, SCell, R0, kpoints, Ds)
+# K_renorm = util.get_K_renorm(tot_atoms_uc,N1,N2,N3, SCell, R0, irr_kpoints, permutations_types, Ds)
 print('Calculated renormalized FORCE CONSTANTS')
 util.save('K_renorm', K_renorm)
