@@ -264,18 +264,17 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
     pgf_with_latex["figure.figsize"] = figsize(1.4)[::-1]
     mpl.rcParams.update(pgf_with_latex)
     n_modes = len(modes)
-    n_kpoints = len(ZQS[0,0,:])
-
+    n_kpoints = len(ZQS[:,0,0])
     for n in range(n_kpoints): #iterating over the k points
         fig, axs = plt.subplots(n_modes, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
         if not (type(axs) == np.ndarray):
             axs = [axs]
         for i in range(n_modes): #iterating over the modes
             mode = modes[i]
-            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[:,0,n].max(),100),c='r', label='freq from dispersion')
-            axs[i].plot(freq,ZQS[:,0,n], ':', color='grey')
+            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[n,:,0].max(),100),c='r', label='freq from dispersion')
+            axs[i].plot(freq,ZQS[n,:,0], ':', color='grey')
             axs[i].text(.75,.75,labels[n]+str('\n mode')+str(mode),fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
-            axs[i].plot(freq, ZQS[:,mode+1,n])
+            axs[i].plot(freq, ZQS[n,:,mode+1])
 
         axs[0].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', top = True, bottom=False)
         axs[-1].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', bottom = True)
@@ -286,8 +285,8 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
         plt.xlabel('Frequency [Thz]')
 #        plt.tight_layout()
         
-    plt.show() 
-    fig.savefig('plot2.pdf')
+        plt.show() 
+        fig.savefig('plot2_'+str(n)+'.pdf')
     return
 
 
@@ -393,7 +392,7 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
     graph_DOS_finiteK,= ax2.plot(DOS_ft,freq_DOS, c='red', label = 'finte K DOS')
 
     ax2.set_xticks([])
-    ax2.tick_params(axis='y', which='major', labelsize=0.0001, width=2 , length=6, direction='in', top=True, right=True)
+    ax2.tick_params(axis='y', which='major', labelsize=0.0, width=2 , length=6, direction='in', top=True, right=True)
     ax2.legend()
     
     
