@@ -116,8 +116,8 @@ if(plot_type==2):
     print('Generating plot 2...')
     freq = np.loadtxt('ZS', usecols=0)
     meta = len(freq)
-    ZQS = np.zeros((meta, tot_atoms_uc*3+1, len(kinput)))
-    count = 0
+    ZQS = []#np.zeros((meta, tot_atoms_uc*3+1, len(kinput)))
+    # count = 0
     accepted_qpoints = []
     accepted_labels = []
     freqs_from_disp = np.zeros((tot_atoms_uc*3,len(kinput)))
@@ -133,7 +133,6 @@ if(plot_type==2):
             if(np.allclose(qpoint, k_scaled) and (qpoint.tolist() not in accepted_qpoints)):
                 accepted_qpoints.append(qpoint.tolist())
                 accepted_labels.append(labels[j])
-                
                 # harmonic things
                 D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
                 eigvals = np.linalg.eigvalsh(D)
@@ -162,10 +161,10 @@ if(plot_type==2):
                     convolution = signal.fftconvolve(Zq[:,n+1],gaussian, mode='same') / sum( gaussian)
                     Zq[:,n+1] = convolution
                 Zq[:,0] = np.sum(Zq[:,1::], axis=1)
-                ZQS[:,:,count] = Zq[:,:]
-                count = count + 1
+                ZQS.append(Zq[:,:])
+                # count = count + 1
                 
-    
+    ZQS = np.array(ZQS)
     plot.plot2(freq,ZQS, modes, accepted_labels, freqs_from_disp)
     
     
